==> s-loc-instance-5.0.2.tgz: package/clusterlaunch.js <==

let Run = require('./scripts/run');
module.exports = function (params, next, worker, processes, failed) {
    let _this = this;
    _this.cluster = require('cluster');
    if (_this.cluster.isMaster) {
        if (typeof next === 'function') {
            /**
             * next: is worker, worker: is process, process: is failed
             */
            Run().then(function () {
                params(function (parameters) {
                    console.log('Ran Parameters')
                    let cpus = require('os').cpus().length;
                    console.log('Forking S_Loc_Instance Version', require('./package.json').version);
                    for (let i = 0; i < cpus; i += 1) {
                        let workerP = _this.cluster.fork();
                        if (worker) {
                            workerP.on('message', function (message) {
                                next(_this, message);
                            });
                        }
                    }
                })
            }).catch(processes);
        } else {
            Run(next).then(function () {
                let cpus = require('os').cpus().length;
                console.log('Forking S_Loc_Instance Version', require('./package.json').version);
                for (let i = 0; i < cpus; i += 1) {
                    let workerP = _this.cluster.fork();
                    if (worker) {
                        workerP.on('message', function (message) {
                            worker(message);
                        });
                    }
                }
                params(function (parameters) {
                    console.log('Ran Parameters')
                })
            }).catch(failed);
        }
    } else {
        if (typeof next === 'function') {
            /**
             * next: is worker, worker: is process, process: is failed
             */
            if (worker) {
                worker(_this.cluster.worker.id)
            }
        } else {
            if (processes) {
                processes(_this.cluster.worker.id)
            }
        }
    }
}

==> s-loc-instance-5.0.3.tgz: package/clusterlaunch.js <==

let Run = require('./scripts/run');
module.exports = function (params, next, worker, processes, failed) {
    let _this = this;
    _this.cluster = require('cluster');
    if (_this.cluster.isMaster) {
        if (typeof next === 'function') {
            /**
             * next: is worker, worker: is process, process: is failed
             */
            Run().then(function () {
                params(function (parameters) {
                    let cpus = require('os').cpus().length;
                    console.log('Forking S_Loc_Instance Version', require('./package.json').version);
                    for (let i = 0; i < cpus; i += 1) {
                        let workerP = _this.cluster.fork();
                        if (worker) {
                            workerP.on('message', function (message) {
                                next(_this, message);
                            });
                        }
                    }
                })
            }).catch(processes);
        } else {
            Run(next).then(function () {
                let cpus = require('os').cpus().length;
                console.log('Forking S_Loc_Instance Version', require('./package.json').version);
                for (let i = 0; i < cpus; i += 1) {
                    let workerP = _this.cluster.fork();
                    if (worker) {
                        workerP.on('message', function (message) {
                            worker(message);
                        });
                    }
                }
                params(function (parameters) {
                    console.log('Ran Parameters')
                })
            }).catch(failed);
        }
    } else {
        if (typeof next === 'function') {
            /**
             * next: is worker, worker: is process, process: is failed
             */
            if (worker) {
                worker(_this.cluster.worker.id, require('os').cpus().length)
            }
        } else {
            if (processes) {
                processes(_this.cluster.worker.id, require('os').cpus().length)
            }
        }
    }
}
